import { __decorate, __metadata, __param } from 'tslib';
import { ɵɵdefineInjectable, Injectable, ElementRef, Optional, Inject, Input, Component, ViewEncapsulation, ChangeDetectionStrategy, NgModule } from '@angular/core';
import { DOCUMENT } from '@angular/common';

let BootstrapIconsRegistry = class BootstrapIconsRegistry {
    constructor() {
        this.registry = new Map();
    }
    registerIcons(icons) {
        icons.forEach((icon) => this.registry.set(icon.name, icon.data));
    }
    getIcon(iconName) {
        if (!this.registry.has(iconName)) {
            console.warn(`We could not find the dinosaur Icon with the name ${iconName}, did you add it to the Icon registry?`);
        }
        return this.registry.get(iconName);
    }
};
BootstrapIconsRegistry.ɵprov = ɵɵdefineInjectable({ factory: function BootstrapIconsRegistry_Factory() { return new BootstrapIconsRegistry(); }, token: BootstrapIconsRegistry, providedIn: "root" });
BootstrapIconsRegistry = __decorate([
    Injectable({
        providedIn: 'root'
    })
], BootstrapIconsRegistry);

let BootstrapIconComponent = class BootstrapIconComponent {
    constructor(element, iconsRegistry, document) {
        this.element = element;
        this.iconsRegistry = iconsRegistry;
        this.document = document;
    }
    set name(iconName) {
        if (this.svgIcon) {
            this.element.nativeElement.removeChild(this.svgIcon);
        }
        const svgData = this.iconsRegistry.getIcon(iconName);
        if (svgData) {
            this.svgIcon = this.svgElementFromString(svgData);
            this.element.nativeElement.appendChild(this.svgIcon);
        }
    }
    svgElementFromString(svgContent) {
        const div = this.document.createElement('DIV');
        if (div instanceof HTMLElement) {
            div.innerHTML = svgContent;
            return div.querySelector('svg') || this.document.createElementNS('http://www.w3.org/2000/svg', 'path');
        }
    }
};
BootstrapIconComponent.ctorParameters = () => [
    { type: ElementRef },
    { type: BootstrapIconsRegistry },
    { type: undefined, decorators: [{ type: Optional }, { type: Inject, args: [DOCUMENT,] }] }
];
__decorate([
    Input(),
    __metadata("design:type", String),
    __metadata("design:paramtypes", [String])
], BootstrapIconComponent.prototype, "name", null);
BootstrapIconComponent = __decorate([
    Component({
        selector: 'bootstrap-icon',
        template: `<ng-content></ng-content>`,
        encapsulation: ViewEncapsulation.None,
        changeDetection: ChangeDetectionStrategy.OnPush
    }),
    __param(2, Optional()), __param(2, Inject(DOCUMENT)),
    __metadata("design:paramtypes", [ElementRef,
        BootstrapIconsRegistry, Object])
], BootstrapIconComponent);

var BootstrapIconsModule_1;
let BootstrapIconsModule = BootstrapIconsModule_1 = class BootstrapIconsModule {
    static forRoot() {
        return {
            ngModule: BootstrapIconsModule_1,
            providers: [
                BootstrapIconsRegistry,
            ],
        };
    }
};
BootstrapIconsModule = BootstrapIconsModule_1 = __decorate([
    NgModule({
        declarations: [BootstrapIconComponent],
        imports: [],
        exports: [BootstrapIconComponent]
    })
], BootstrapIconsModule);

/*
 * Public API Surface of the icons lib
 */

/**
 * Generated bundle index. Do not edit.
 */

export { BootstrapIconComponent, BootstrapIconsModule, BootstrapIconsRegistry };
//# sourceMappingURL=triangular-bootstrap-icons.js.map
